import path from "path";
import fs from "fs-extra";
import getPublicUrlOrPath from "../common/utils/getPublicUrlOrPath.mjs";
const getPaths = (userConfig) => {
  const appDirectory = fs.realpathSync(process.cwd());
  const resolveApp = (relativePath) => path.resolve(appDirectory, relativePath);
  const publicUrlOrPath = getPublicUrlOrPath(
    process.env.NODE_ENV === "development",
    require(resolveApp("package.json")).homepage,
    process.env.PUBLIC_URL
  );
  const { distDir } = userConfig;
  const moduleFileExtensions = [
    "web.mjs",
    "mjs",
    "web.js",
    "js",
    "web.ts",
    "ts",
    "web.tsx",
    "tsx",
    "json",
    "web.jsx",
    "jsx"
  ];
  const resolveModule = (resolveFn, filePath) => {
    const extension = moduleFileExtensions.find(
      (e) => fs.pathExistsSync(resolveFn(`${filePath}.${e}`))
    );
    if (extension) {
      return resolveFn(`${filePath}.${extension}`);
    }
    return resolveFn(`${filePath}.js`);
  };
  const paths = {
    dotenv: resolveApp(".env"),
    appPath: resolveApp("."),
    appDist: resolveApp(distDir),
    appPublic: resolveApp("public"),
    appHtml: resolveApp("public/index.html"),
    appIndexJs: resolveModule(resolveApp, "src/index"),
    appPackageJson: resolveApp("package.json"),
    appSrc: resolveApp("src"),
    appTsConfig: resolveApp("tsconfig.json"),
    appJsConfig: resolveApp("jsconfig.json"),
    proxySetup: resolveApp("src/setupProxy.js"),
    appNodeModules: resolveApp("node_modules"),
    appWebpackCache: resolveApp("node_modules/.cache"),
    appTsBuildInfoFile: resolveApp("node_modules/.cache/tsconfig.tsbuildinfo"),
    swSrc: resolveModule(resolveApp, "src/service-worker"),
    publicUrlOrPath,
    svgSpritePath: resolveApp("src/icons/svg"),
    moduleFileExtensions
  };
  return paths;
};
export {
  getPaths
};
