import path from "node:path";
import pico from "picocolors";
import table from "text-table";
import stripAnsi from "./stripAnsi.mjs";
const cwd = process.cwd();
const emitErrorsAsWarnings = process.env.NODE_ENV === "development" && process.env.ESLINT_NO_DEV_ERRORS === "true";
const isError = (message) => {
  return message.fatal || message.severity === 2;
};
const getRelativePath = (filePath) => path.relative(cwd, filePath);
const formatter = (results) => {
  let output = "\n";
  let hasErrors = false;
  let reportContainsErrorRuleIDs = false;
  results.forEach((result) => {
    let messages = result.messages;
    if (messages.length === 0) {
      return;
    }
    messages = messages.map((message) => {
      let messageType;
      if (isError(message) && !emitErrorsAsWarnings) {
        messageType = "error";
        hasErrors = true;
        if (message.ruleId) {
          reportContainsErrorRuleIDs = true;
        }
      } else {
        messageType = "warn";
      }
      let line = message.line || 0;
      if (message.column) {
        line += ":" + message.column;
      }
      const position = pico.bold("Line " + line + ":");
      return [
        "",
        position,
        messageType,
        message.message.replace(/\.$/, ""),
        pico.underline(message.ruleId || "")
      ];
    });
    if (hasErrors) {
      messages = messages.filter((m) => m[2] === "error");
    }
    messages.forEach((m) => {
      m[4] = m[2] === "error" ? pico.red(m[4]) : pico.yellow(m[4]);
      m.splice(2, 1);
    });
    const outputTable = table(messages, {
      align: ["l", "l", "l"],
      stringLength(str) {
        return stripAnsi(str).length;
      }
    });
    output += `${getRelativePath(result.filePath)}
`;
    output += `${outputTable}

`;
  });
  if (reportContainsErrorRuleIDs) {
    output += "Search for the " + pico.underline(pico.red("keywords")) + " to learn more about each error.";
  }
  return output;
};
var eslintFormatter_default = formatter;
export {
  eslintFormatter_default as default
};
