import { fileURLToPath } from "url";
import path from "path";
var getFilename = () => fileURLToPath(import.meta.url);
var getDirname = () => path.dirname(getFilename());
var __dirname = /* @__PURE__ */ getDirname();
var __filename = /* @__PURE__ */ getFilename();
import { execSync, spawn } from "child_process";
import pico from "picocolors";
import open from "open";
const OSX_CHROME = "google chrome";
var Actions = /* @__PURE__ */ ((Actions2) => {
  Actions2[Actions2["NONE"] = 0] = "NONE";
  Actions2[Actions2["BROWSER"] = 1] = "BROWSER";
  Actions2[Actions2["SCRIPT"] = 2] = "SCRIPT";
  return Actions2;
})(Actions || {});
const getBrowserEnv = () => {
  const value = process.env.BROWSER;
  const args = process.env.BROWSER_ARGS ? process.env.BROWSER_ARGS.split(" ") : [];
  let action;
  if (!value) {
    action = 1 /* BROWSER */;
  } else if (value.toLowerCase().endsWith(".js")) {
    action = 2 /* SCRIPT */;
  } else if (value.toLowerCase() === "none") {
    action = 0 /* NONE */;
  } else {
    action = 1 /* BROWSER */;
  }
  return { action, value, args };
};
const executeNodeScript = (scriptPath, url) => {
  const extraArgs = process.argv.slice(2);
  const child = spawn(process.execPath, [scriptPath, ...extraArgs, url], {
    stdio: "inherit"
  });
  child.on("close", (code) => {
    if (code !== 0) {
      console.log();
      console.log(
        pico.red(
          "The script specified as BROWSER environment variable failed."
        )
      );
      console.log(pico.cyan(scriptPath) + " exited with code " + code + ".");
      console.log();
      return;
    }
  });
  return true;
};
const startBrowserProcess = (browser, url, args) => {
  const shouldTryOpenChromiumWithAppleScript = process.platform === "darwin" && (typeof browser !== "string" || browser === OSX_CHROME);
  if (shouldTryOpenChromiumWithAppleScript) {
    const supportedChromiumBrowsers = [
      "Google Chrome Canary",
      "Google Chrome",
      "Microsoft Edge",
      "Brave Browser",
      "Vivaldi",
      "Chromium"
    ];
    for (const chromiumBrowser of supportedChromiumBrowsers) {
      try {
        execSync('ps cax | grep "' + chromiumBrowser + '"');
        execSync(
          'osascript openChrome.applescript "' + encodeURI(url) + '" "' + chromiumBrowser + '"',
          {
            cwd: __dirname,
            stdio: "ignore"
          }
        );
        return true;
      } catch (err) {
      }
    }
  }
  if (process.platform === "darwin" && browser === "open") {
    browser = void 0;
  }
  if (typeof browser === "string" && args.length > 0) {
    browser = [browser].concat(args);
  }
  try {
    const options = { app: browser, wait: false, url: true };
    open(url, options).catch(() => {
    });
    return true;
  } catch (err) {
    return false;
  }
};
const openBrowser = (url) => {
  const { action, value, args } = getBrowserEnv();
  switch (action) {
    case 0 /* NONE */:
      return false;
    case 2 /* SCRIPT */:
      return executeNodeScript(value, url);
    case 1 /* BROWSER */:
      return startBrowserProcess(value, url, args);
    default:
      throw new Error("Not implemented.");
  }
};
var openBrowser_default = openBrowser;
export {
  openBrowser_default as default
};
