import path from "path";
import { defineConfig, loadConfig, mergeRsbuildConfig } from "@rsbuild/core";
import { pluginReact } from "@rsbuild/plugin-react";
import { pluginTypeCheck } from "@rsbuild/plugin-type-check";
import { pluginSvgr } from "@rsbuild/plugin-svgr";
import { pluginStylus } from "@rsbuild/plugin-stylus";
import { getEnv } from "../../common/getEnv.mjs";
const getRsbuildConfig = async (devConfig, paths) => {
  const env = getEnv(paths.publicUrlOrPath.slice(0, -1));
  const defaultConfig = defineConfig({
    plugins: [
      pluginReact(),
      pluginTypeCheck(),
      pluginSvgr(),
      pluginStylus()
      // pluginCheckSyntax(),
    ],
    output: {
      polyfill: "entry",
      legalComments: "none",
      filename: process.env.NODE_ENV === "production" ? {
        js: "[name].[contenthash:16].js",
        css: "[name].[contenthash:16].css",
        svg: "[name].[contenthash:16].svg",
        font: "[name].[contenthash:16][ext]",
        image: "[name].[contenthash:16][ext]",
        media: "[name].[contenthash:16][ext]"
      } : {
        js: "[name].js",
        css: "[name].css",
        svg: "[name].[contenthash:16].svg",
        font: "[name].[contenthash:16][ext]",
        image: "[name].[contenthash:16][ext]",
        media: "[name].[contenthash:16][ext]"
      }
    },
    tools: {
      postcss: (config, { addPlugins }) => {
      }
    },
    source: {
      define: env.stringified
    },
    performance: { prefetch: true }
  });
  const userConfig = await loadConfig({
    cwd: process.cwd(),
    path: path.join(process.cwd(), "mango.config.mjs")
  });
  return mergeRsbuildConfig(defaultConfig, devConfig, userConfig);
};
export {
  getRsbuildConfig
};
